import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { DeleteOrganizationRequest, DeleteOrganizationResponse } from "../models/models_0";
import { ServiceInputTypes, ServiceOutputTypes, WorkMailClientResolvedConfig } from "../WorkMailClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DeleteOrganizationCommand}.
 */
export interface DeleteOrganizationCommandInput extends DeleteOrganizationRequest {
}
/**
 * @public
 *
 * The output of {@link DeleteOrganizationCommand}.
 */
export interface DeleteOrganizationCommandOutput extends DeleteOrganizationResponse, __MetadataBearer {
}
declare const DeleteOrganizationCommand_base: {
    new (input: DeleteOrganizationCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteOrganizationCommandInput, DeleteOrganizationCommandOutput, WorkMailClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DeleteOrganizationCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteOrganizationCommandInput, DeleteOrganizationCommandOutput, WorkMailClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Deletes an WorkMail organization and all underlying AWS resources managed by WorkMail as part of the organization. You can choose whether to delete the associated directory. For more information, see <a href="https://docs.aws.amazon.com/workmail/latest/adminguide/remove_organization.html">Removing an organization</a> in the <i>WorkMail Administrator Guide</i>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { WorkMailClient, DeleteOrganizationCommand } from "@aws-sdk/client-workmail"; // ES Modules import
 * // const { WorkMailClient, DeleteOrganizationCommand } = require("@aws-sdk/client-workmail"); // CommonJS import
 * const client = new WorkMailClient(config);
 * const input = { // DeleteOrganizationRequest
 *   ClientToken: "STRING_VALUE",
 *   OrganizationId: "STRING_VALUE", // required
 *   DeleteDirectory: true || false, // required
 *   ForceDelete: true || false,
 *   DeleteIdentityCenterApplication: true || false,
 * };
 * const command = new DeleteOrganizationCommand(input);
 * const response = await client.send(command);
 * // { // DeleteOrganizationResponse
 * //   OrganizationId: "STRING_VALUE",
 * //   State: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param DeleteOrganizationCommandInput - {@link DeleteOrganizationCommandInput}
 * @returns {@link DeleteOrganizationCommandOutput}
 * @see {@link DeleteOrganizationCommandInput} for command's `input` shape.
 * @see {@link DeleteOrganizationCommandOutput} for command's `response` shape.
 * @see {@link WorkMailClientResolvedConfig | config} for WorkMailClient's `config` shape.
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the input parameters don't match the service's restrictions.</p>
 *
 * @throws {@link OrganizationNotFoundException} (client fault)
 *  <p>An operation received a valid organization identifier that either doesn't belong or
 *          exist in the system.</p>
 *
 * @throws {@link OrganizationStateException} (client fault)
 *  <p>The organization must have a valid state to perform certain
 *          operations on the organization or its members.</p>
 *
 * @throws {@link WorkMailServiceException}
 * <p>Base exception class for all service exceptions from WorkMail service.</p>
 *
 * @public
 */
export declare class DeleteOrganizationCommand extends DeleteOrganizationCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DeleteOrganizationRequest;
            output: DeleteOrganizationResponse;
        };
        sdk: {
            input: DeleteOrganizationCommandInput;
            output: DeleteOrganizationCommandOutput;
        };
    };
}
